import os
import importlib

from geniverse_hub.hub_config import HUB_CONFIG_DICT, HUB_MODULE_DIR


def load_from_hub(module_name: str, ):
    try:
        print(f"Loading {module_name}...")
        hub_module_utils = importlib.import_module(
            f"{module_name}.modeling_utils")

        return hub_module_utils

    except:
        module_config = [
            config_dict for config_dict in HUB_CONFIG_DICT["modules"]
            if config_dict["name"] == module_name
        ][0]

        module_owner = module_config["owner"]
        module_name = module_config["name"]
        module_dist = module_config["dist"]

        print(f"Initiating {module_name} from {module_owner}")

        requirement_name = f"https://github.com/{module_owner}/{module_name}/archive/{module_dist}.zip"
        print(f"Whoops! You do not have {module_name} installed")
        print("Run the following command to install it:")
        print(f"pip install {requirement_name}")

        return None



import os
import sys

from geniverse_hub.hub_utils import HUB_CONFIG_DICT

module_name_list = [conf["name"] for conf in HUB_CONFIG_DICT["modules"]]
for module_name in module_name_list:
    module_path = f"./geniverse_hub/{module_name}"

    if os.path.exists(module_path):
        print(f"{module_name} module found and added to path!")
        sys.path.append(module_path)



import os
import urllib.request
import json

HUB_MODULE_DIR = os.path.dirname(__file__)

HUB_CONFIG_PATH = os.path.join(HUB_MODULE_DIR, "./hub_config.json")

# hub_config_url = "https://raw.githubusercontent.com/thegeniverse/geniverse_hub/main/geniverse_hub/hub_config.json"
# res = urllib.request.urlopen(hub_config_url).read()
# HUB_CONFIG_DICT = json.loads(res)

HUB_CONFIG_DICT = {
    "modules": [{
        "owner": "thegeniverse",
        "name": "taming",
        "dist": "master"
    }, {
        "owner": "thegeniverse",
        "name": "clip",
        "dist": "main"
    }, {
        "owner": "thegeniverse",
        "name": "glide",
        "dist": "main"
    }, {
        "owner": "thegeniverse",
        "name": "u2net",
        "dist": "master"
    }]
}
